@@ -1,8 +1,8 @@
-"""
-Unix system checks.
+"""Unix system checks.
 """
 
 # stdlib
+import functools
 import logging
 import operator
 import platform
@@ -12,22 +12,24 @@ import sys
 import time
 
 # project
-from monagent.collector.checks.check import Check
-from monagent.common.metrics import Measurement
-from monagent.common.util import Platform
-from functools import reduce
+
+import monagent.collector.checks.check
+import monagent.common.metrics
+import monagent.common.util
 
 
 # locale-resilient float converter
 to_float = lambda s: float(s.replace(",", "."))
 
 
-class Disk(Check):
+class Disk(monagent.collector.checks.check.Check):
 
-    """ Collects metrics about the machine's disks. """
+    """Collects metrics about the machine's disks.
+    """
 
     def check(self):
-        """Get disk space/inode stats"""
+        """Get disk space/inode stats.
+        """
         # First get the configuration.
         if self.agent_config is not None:
             use_mount = self.agent_config.get("use_mount", False)
@@ -58,12 +60,12 @@ class Disk(Check):
             # parse into a list of Measurements
             stats.update(inodes)
             timestamp = time.time()
-            measurements = [
-                Measurement(
-                    key.split(
-                        '.', 1)[1], timestamp, value, {
-                        'device': key.split(
-                            '.', 1)[0]}) for key, value in stats.iteritems()]
+            measurements = [monagent.common.metrics.Measurement(key.split('.', 1)[1],
+                                                                timestamp,
+                                                                value,
+                                                                {'device': key.split('.', 1)[0]})
+                            for key, value in stats.iteritems()]
+
             return measurements
 
         except Exception:
@@ -72,9 +74,9 @@ class Disk(Check):
 
     def parse_df_output(
             self, df_output, platform_name, inodes=False, use_mount=False, blacklist_re=None):
-        """
-        Parse the output of the df command. If use_volume is true the volume
-        is used to anchor the metric, otherwise false the mount
+        """Parse the output of the df command.
+
+        If use_volume is true the volume is used to anchor the metric, otherwise false the mount
         point is used. Returns a tuple of (disk, inode).
         """
         usage_data = {}
@@ -88,14 +90,14 @@ class Disk(Check):
                 if use_mount:
                     parts[0] = parts[-1]
                 if inodes:
-                    if Platform.is_darwin(platform_name):
+                    if monagent.common.util.Platform.is_darwin(platform_name):
                         # Filesystem 512-blocks Used Available Capacity iused ifree %iused  Mounted
                         # Inodes are in position 5, 6 and we need to compute the total
                         # Total
                         parts[1] = int(parts[5]) + int(parts[6])  # Total
                         parts[2] = int(parts[5])  # Used
                         parts[3] = int(parts[6])  # Available
-                    elif Platform.is_freebsd(platform_name):
+                    elif monagent.common.util.Platform.is_freebsd(platform_name):
                         # Filesystem 1K-blocks Used Avail Capacity iused ifree %iused Mounted
                         # Inodes are in position 5, 6 and we need to compute the total
                         parts[1] = int(parts[5]) + int(parts[6])  # Total
@@ -113,13 +115,9 @@ class Disk(Check):
                 self.logger.exception("Cannot parse %s" % (parts,))
 
             if inodes:
-                usage_data['%s.disk_total_inodes' % parts[0]] = parts[1]
-                usage_data['%s.disk_used_inodes' % parts[0]] = parts[2]
-                usage_data['%s.disk_free_inodes' % parts[0]] = parts[3]
+                usage_data['%s.disk_inode_utilization_perc' % parts[0]] = float(parts[2]) / parts[1] * 100
             else:
-                usage_data['%s.disk_total_kbytes' % parts[0]] = parts[1]
-                usage_data['%s.disk_used_kbytes' % parts[0]] = parts[2]
-                usage_data['%s.disk_free_kbytes' % parts[0]] = parts[3]
+                usage_data['%s.disk_space_utilization_perc' % parts[0]] = float(parts[2]) / parts[1] * 100
 
         return usage_data
 
@@ -132,8 +130,7 @@ class Disk(Check):
         return True
 
     def _is_real_device(self, device):
-        """
-        Return true if we should track the given device name and false otherwise.
+        """Return true if we should track the given device name and false otherwise.
         """
         # First, skip empty lines.
         if not device or len(device) <= 1:
@@ -168,10 +165,9 @@ class Disk(Check):
         return devices
 
     def _transform_df_output(self, df_output, blacklist_re):
-        """
-        Given raw output for the df command, transform it into a normalized
-        list devices. A 'device' is a list with fields corresponding to the
-        output of df output on each platform.
+        """Given raw output for the df command, transform it into a normalized list devices.
+
+        A 'device' is a list with fields corresponding to the output of df output on each platform.
         """
         all_devices = [l.strip().split() for l in df_output.split("\n")]
 
@@ -194,10 +190,10 @@ class Disk(Check):
         return devices
 
 
-class IO(Check):
+class IO(monagent.collector.checks.check.Check):
 
     def __init__(self, logger):
-        Check.__init__(self, logger)
+        monagent.collector.checks.check.Check.__init__(self, logger)
         self.header_re = re.compile(r'([%\\/\-_a-zA-Z0-9]+)[\s+]?')
         self.item_re = re.compile(r'^([a-zA-Z0-9\/]+)')
         self.value_re = re.compile(r'\d+\.\d+')
@@ -256,25 +252,26 @@ class IO(Check):
 
     @staticmethod
     def xlate(metric_name, os_name):
-        """Standardize on linux metric names"""
+        """Standardize on linux metric names.
+        """
         if os_name == "sunos":
             names = {"wait": "await",
                      "svc_t": "svctm",
                      "%b": "%util",
-                     "kr/s": "io_read_kbytes_sec",
-                     "kw/s": "io_write_kbytes_sec",
+                     "kr/s": "io.read_kbytes_sec",
+                     "kw/s": "io.write_kbytes_sec",
                      "actv": "avgqu-sz"}
         elif os_name == "freebsd":
             names = {"svc_t": "await",
                      "%b": "%util",
-                     "kr/s": "io_read_kbytes_sec",
-                     "kw/s": "io_write_kbytes_sec",
+                     "kr/s": "io.read_kbytes_sec",
+                     "kw/s": "io.write_kbytes_sec",
                      "wait": "avgqu-sz"}
         elif os_name == "linux":
-            names = {"rkB/s": "io_read_kbytes_sec",
-                     "r/s": "io_read_req_sec",
-                     "wkB/s": "io_write_kbytes_sec",
-                     "w/s": "io_write_req_sec"}
+            names = {"rkB/s": "io.read_kbytes_sec",
+                     "r/s": "io.read_req_sec",
+                     "wkB/s": "io.write_kbytes_sec",
+                     "w/s": "io.write_req_sec"}
         # translate if possible
         return names.get(metric_name, metric_name)
 
@@ -286,7 +283,7 @@ class IO(Check):
         """
         io = {}
         try:
-            if Platform.is_linux():
+            if monagent.common.util.Platform.is_linux():
                 stdout = sp.Popen(['iostat', '-d', '1', '2', '-x', '-k'],
                                   stdout=sp.PIPE,
                                   close_fds=True).communicate()[0]
@@ -398,7 +395,7 @@ class IO(Check):
             for dev_name, stats in filtered_io.iteritems():
                 filtered_stats = {stat: stats[stat]
                                   for stat in stats.iterkeys() if stat not in self.stat_blacklist}
-                m_list = [Measurement(key, timestamp, value, {'device': dev_name})
+                m_list = [monagent.common.metrics.Measurement(key, timestamp, value, {'device': dev_name})
                           for key, value in filtered_stats.iteritems()]
                 measurements.extend(m_list)
 
@@ -409,10 +406,10 @@ class IO(Check):
             return {}
 
 
-class Load(Check):
+class Load(monagent.collector.checks.check.Check):
 
     def check(self):
-        if Platform.is_linux():
+        if monagent.common.util.Platform.is_linux():
             try:
                 loadAvrgProc = open('/proc/loadavg', 'r')
                 uptime = loadAvrgProc.readlines()
@@ -435,16 +432,16 @@ class Load(Check):
 
         # Split out the 3 load average values
         load = [res.replace(',', '.') for res in re.findall(r'([0-9]+[\.,]\d+)', uptime)]
-        return {'load_avg_1_min': float(load[0]),
-                'load_avg_5_min': float(load[1]),
-                'load_avg_15_min': float(load[2]),
+        return {'cpu.load_avg_1_min': float(load[0]),
+                'cpu.load_avg_5_min': float(load[1]),
+                'cpu.load_avg_15_min': float(load[2]),
                 }
 
 
-class Memory(Check):
+class Memory(monagent.collector.checks.check.Check):
 
     def __init__(self, logger):
-        Check.__init__(self, logger)
+        monagent.collector.checks.check.Check.__init__(self, logger)
         macV = None
         if sys.platform == 'darwin':
             macV = platform.mac_ver()
@@ -468,7 +465,7 @@ class Memory(Check):
                 pass
 
     def check(self):
-        if Platform.is_linux():
+        if monagent.common.util.Platform.is_linux():
             try:
                 meminfoProc = open('/proc/meminfo', 'r')
                 lines = meminfoProc.readlines()
@@ -537,35 +534,35 @@ class Memory(Check):
             # Physical memory
             # FIXME units are in MB, we should use bytes instead
             try:
-                memData['mem_total_mb'] = int(meminfo.get('MemTotal', 0)) / 1024
-                memData['mem_free_mb'] = int(meminfo.get('MemFree', 0)) / 1024
-                memData['memphysBuffers'] = int(meminfo.get('Buffers', 0)) / 1024
-                memData['memphysCached'] = int(meminfo.get('Cached', 0)) / 1024
-                memData['memphysShared'] = int(meminfo.get('Shmem', 0)) / 1024
+                memData['mem.total_mb'] = int(meminfo.get('MemTotal', 0)) / 1024
+                memData['mem.free_mb'] = int(meminfo.get('MemFree', 0)) / 1024
+                memData['mem.used_buffers'] = int(meminfo.get('Buffers', 0)) / 1024
+                memData['mem.used_cached'] = int(meminfo.get('Cached', 0)) / 1024
+                memData['mem.used_shared'] = int(meminfo.get('Shmem', 0)) / 1024
 
-                memData['mem_usable_perc'] = memData['mem_total_mb'] - memData['mem_free_mb']
+                memData['mem.usable_perc'] = memData['mem.total_mb'] - memData['mem.free_mb']
                 # Usable is relative since cached and buffers are actually used to speed things up.
-                memData['mem_usable_mb'] = memData['mem_free_mb'] + \
-                    memData['memphysBuffers'] + memData['memphysCached']
+                memData['mem.usable_mb'] = memData['mem.free_mb'] + \
+                    memData['mem.used_buffers'] + memData['mem.used_cached']
 
-                if memData['mem_total_mb'] > 0:
-                    memData['mem_usable_perc'] = float(
-                        memData['mem_usable_mb']) / float(memData['mem_total_mb'])
+                if memData['mem.total_mb'] > 0:
+                    memData['mem.usable_perc'] = float(
+                        memData['mem.usable_mb']) / float(memData['mem.total_mb'])
             except Exception:
                 self.logger.exception('Cannot compute stats from /proc/meminfo')
 
             # Swap
             # FIXME units are in MB, we should use bytes instead
             try:
-                memData['mem_swap_total_mb'] = int(meminfo.get('SwapTotal', 0)) / 1024
-                memData['mem_swap_free_mb'] = int(meminfo.get('SwapFree', 0)) / 1024
+                memData['mem.swap_total_mb'] = int(meminfo.get('SwapTotal', 0)) / 1024
+                memData['mem.swap_free_mb'] = int(meminfo.get('SwapFree', 0)) / 1024
 
-                memData['mem_swap_used_mb'] = memData[
-                    'mem_swap_total_mb'] - memData['mem_swap_free_mb']
+                memData['mem.swap_used_mb'] = memData[
+                    'mem.swap_total_mb'] - memData['mem.swap_free_mb']
 
-                if memData['mem_swap_total_mb'] > 0:
-                    memData['mem_swap_free_perc'] = float(
-                        memData['mem_swap_free_mb']) / float(memData['mem_swap_total_mb'])
+                if memData['mem.swap_total_mb'] > 0:
+                    memData['mem.swap_free_perc'] = float(
+                        memData['mem.swap_free_mb']) / float(memData['mem.swap_total_mb'])
             except Exception:
                 self.logger.exception('Cannot compute swap stats')
 
@@ -740,25 +737,27 @@ class Memory(Check):
             return {}
 
 
-class Cpu(Check):
+class Cpu(monagent.collector.checks.check.Check):
 
     def check(self):
-        """Return an aggregate of CPU stats across all CPUs
+        """Return an aggregate of CPU stats across all CPUs.
+
         When figures are not available, False is sent back.
         """
         def format_results(us, sy, wa, idle, st):
-            data = {'cpu_user_perc': us,
-                    'cpu_system_perc': sy,
-                    'cpu_wait_perc': wa,
-                    'cpu_idle_perc': idle,
-                    'cpu_stolen_perc': st}
+            data = {'cpu.user_perc': us,
+                    'cpu.system_perc': sy,
+                    'cpu.wait_perc': wa,
+                    'cpu.idle_perc': idle,
+                    'cpu.stolen_perc': st}
             for key in data.keys():
                 if data[key] is None:
                     del data[key]
             return data
 
         def get_value(legend, data, name, filter_value=None):
-            "Using the legend and a metric name, get the value or None from the data line"
+            """Using the legend and a metric name, get the value or None from the data line.
+            """
             if name in legend:
                 value = to_float(data[legend.index(name)])
                 if filter_value is not None:
@@ -771,7 +770,7 @@ class Cpu(Check):
                 self.logger.debug("Cannot extract cpu value %s from %s (%s)" % (name, data, legend))
                 return 0.0
 
-        if Platform.is_linux():
+        if monagent.common.util.Platform.is_linux():
             mpstat = sp.Popen(['mpstat', '1', '3'], stdout=sp.PIPE, close_fds=True).communicate()[0]
             # topdog@ip:~$ mpstat 1 3
             # Linux 2.6.32-341-ec2 (ip)   01/19/2012  _x86_64_  (2 CPU)
@@ -921,7 +920,7 @@ class Cpu(Check):
                     size = [get_value(headers, l.split(), "sze") for l in d_lines]
                     count = sum(size)
                     rel_size = [s / count for s in size]
-                    dot = lambda v1, v2: reduce(operator.add, map(operator.mul, v1, v2))
+                    dot = lambda v1, v2: functools.reduce(operator.add, map(operator.mul, v1, v2))
                     return format_results(dot(user, rel_size),
                                           dot(kern, rel_size),
                                           dot(wait, rel_size),
@@ -936,9 +935,9 @@ class Cpu(Check):
 
 
 def _get_subprocess_output(command):
-    """
-    Run the given subprocess command and return it's output. Raise an Exception
-    if an error occurs.
+    """Run the given subprocess command and return it's output.
+
+    Raise an Exception if an error occurs.
     """
     proc = sp.Popen(command, stdout=sp.PIPE, close_fds=True)
     return proc.stdout.read()
