@@ -75,9 +75,4 @@ def get_check(name, config_str):
         raise Exception(
             "Unable to import check %s. Missing a class that inherits AgentCheck" % name)
 
-    agent_config = {
-        'version': '0.1',
-        'api_key': 'tota'
-    }
-
     return check_class.from_yaml(yaml_text=config_str, check_name=name)
