@@ -1,3 +1,4 @@
+from __future__ import print_function
 import logging
 import unittest
 from tempfile import NamedTemporaryFile
@@ -100,7 +101,7 @@ class TailTestCase(unittest.TestCase):
 
     def _write_log(self, log_data):
         for data in log_data:
-            print >> self.log_file, data
+            print(data, file=self.log_file)
         self.log_file.flush()
 
     def tearDown(self):
@@ -147,7 +148,7 @@ class TestDogstream(TailTestCase):
         self._write_log((' '.join(data) for data in log_data))
 
         actual_output = self.dogstream.check(self.config, move_end=False)
-        self.assertEquals(expected_output, actual_output)
+        self.assertEqual(expected_output, actual_output)
         for metric, timestamp, val, attr in expected_output['dogstream']:
             assert isinstance(val, float)
 
@@ -176,7 +177,7 @@ class TestDogstream(TailTestCase):
         self._write_log((' '.join(data) for data in log_data))
 
         actual_output = self.dogstream.check(self.config, move_end=False)
-        self.assertEquals(expected_output, actual_output)
+        self.assertEqual(expected_output, actual_output)
         for metric, timestamp, val, attr in expected_output['dogstream']:
             assert isinstance(val, (int, long))
 
@@ -192,7 +193,7 @@ class TestDogstream(TailTestCase):
         self._write_log(log_data)
 
         actual_output = self.dogstream.check(self.config, move_end=False)
-        self.assertEquals(expected_output, actual_output)
+        self.assertEqual(expected_output, actual_output)
 
     def test_dogstream_ancient_function_plugin(self):
         """Ensure that pre-stateful plugins still work"""
@@ -211,6 +212,7 @@ class TestDogstream(TailTestCase):
                 'dogstreams': '%s:tests.test_datadog:parse_ancient_function_plugin' %
                 self.log_file.name})
         actual_output = plugdog.check(self.config, move_end=False)
+        self.assertEqual(expected_output, actual_output)
 
     def test_dogstream_function_plugin(self):
         """Ensure that non-class-based stateful plugins work"""
@@ -229,7 +231,7 @@ class TestDogstream(TailTestCase):
             self.logger,
             {'dogstreams': '%s:tests.test_datadog:parse_function_plugin' % self.log_file.name})
         actual_output = statedog.check(self.config, move_end=False)
-        self.assertEquals(expected_output, actual_output)
+        self.assertEqual(expected_output, actual_output)
 
     def test_dogstream_new_plugin(self):
         """Ensure that class-based stateful plugins work"""
@@ -248,7 +250,7 @@ class TestDogstream(TailTestCase):
             self.logger,
             {'dogstreams': '%s:tests.test_datadog:ParseClassPlugin:foo:bar' % self.log_file.name})
         actual_output = statedog.check(self.config, move_end=False)
-        self.assertEquals(expected_output, actual_output)
+        self.assertEqual(expected_output, actual_output)
 
     def test_dogstream_events(self):
         log_data = [
@@ -300,7 +302,7 @@ class TestDogstream(TailTestCase):
         dogstream = Dogstreams.init(
             self.logger, {'dogstreams': '%s:tests.test_datadog:parse_events' % self.log_file.name})
         actual_output = dogstream.check(self.config, move_end=False)
-        self.assertEquals(expected_output, actual_output)
+        self.assertEqual(expected_output, actual_output)
 
     def test_dogstream_events_validation(self):
         log_data = [
@@ -336,7 +338,7 @@ class TestDogstream(TailTestCase):
             self.logger,
             {'dogstreams': '%s:tests.test_datadog:repr_event_parser' % self.log_file.name})
         actual_output = dogstream.check(self.config, move_end=False)
-        self.assertEquals(expected_output, actual_output)
+        self.assertEqual(expected_output, actual_output)
 
     def test_cassandra_parser(self):
 
@@ -407,7 +409,7 @@ class TestDogstream(TailTestCase):
             self.logger,
             {'dogstreams': '%s:dogstream.cassandra:parse_cassandra' % self.log_file.name})
         actual_output = dogstream.check(self.config, move_end=False)
-        self.assertEquals(expected_output, actual_output)
+        self.assertEqual(expected_output, actual_output)
 
     def test_supervisord_parser(self):
         log_data = """2012-07-16 22:30:48,335 INFO spawned: 'monitor' with pid 20216
@@ -452,7 +454,7 @@ class TestDogstream(TailTestCase):
             self.logger,
             {'dogstreams': '%s:dogstream.supervisord_log:parse_supervisord' % self.log_file.name})
         actual_output = dogstream.check(self.config, move_end=False)
-        self.assertEquals(expected_output, actual_output)
+        self.assertEqual(expected_output, actual_output)
 
 
 class TestNagiosPerfData(TailTestCase):
@@ -469,7 +471,7 @@ class TestNagiosPerfData(TailTestCase):
 
     def _write_nagios_config(self, config_data):
         for data in config_data:
-            print >> self.nagios_config, data
+            print(data, file=self.nagios_config)
         self.nagios_config.flush()
 
     def tearDown(self):
@@ -485,7 +487,7 @@ class TestNagiosPerfData(TailTestCase):
         ])
 
         dogstream = Dogstreams.init(self.logger, self.agent_config)
-        self.assertEquals([NagiosServicePerfData], [d.__class__ for d in dogstream.dogstreams])
+        self.assertEqual([NagiosServicePerfData], [d.__class__ for d in dogstream.dogstreams])
 
         log_data = [
             (
@@ -553,7 +555,7 @@ class TestNagiosPerfData(TailTestCase):
         actual_output = dogstream.check(self.agent_config, move_end=False)['dogstream']
         actual_output.sort(key=point_sorter)
 
-        self.assertEquals(expected_output, actual_output)
+        self.assertEqual(expected_output, actual_output)
 
     def test_service_perfdata_special_cases(self):
         from collector.checks.datadog import NagiosServicePerfData
@@ -564,7 +566,7 @@ class TestNagiosPerfData(TailTestCase):
         ])
 
         dogstream = Dogstreams.init(self.logger, self.agent_config)
-        self.assertEquals([NagiosServicePerfData], [d.__class__ for d in dogstream.dogstreams])
+        self.assertEqual([NagiosServicePerfData], [d.__class__ for d in dogstream.dogstreams])
 
         log_data = [
             (
@@ -679,7 +681,7 @@ class TestNagiosPerfData(TailTestCase):
         actual_output = dogstream.check(self.agent_config, move_end=False)['dogstream']
         actual_output.sort(key=point_sorter)
 
-        self.assertEquals(expected_output, actual_output)
+        self.assertEqual(expected_output, actual_output)
 
     def test_host_perfdata(self):
         from collector.checks.datadog import NagiosHostPerfData
@@ -690,7 +692,7 @@ class TestNagiosPerfData(TailTestCase):
         ])
 
         dogstream = Dogstreams.init(self.logger, self.agent_config)
-        self.assertEquals([NagiosHostPerfData], [d.__class__ for d in dogstream.dogstreams])
+        self.assertEqual([NagiosHostPerfData], [d.__class__ for d in dogstream.dogstreams])
 
         log_data = [
             (
@@ -732,7 +734,7 @@ class TestNagiosPerfData(TailTestCase):
         actual_output = dogstream.check(self.agent_config, move_end=False)['dogstream']
         actual_output.sort(key=point_sorter)
 
-        self.assertEquals(expected_output, actual_output)
+        self.assertEqual(expected_output, actual_output)
 
     def test_alt_service_perfdata(self):
         from collector.checks.datadog import NagiosServicePerfData
@@ -743,7 +745,7 @@ class TestNagiosPerfData(TailTestCase):
         ])
 
         dogstream = Dogstreams.init(self.logger, self.agent_config)
-        self.assertEquals([NagiosServicePerfData], [d.__class__ for d in dogstream.dogstreams])
+        self.assertEqual([NagiosServicePerfData], [d.__class__ for d in dogstream.dogstreams])
         actual_output = dogstream.check(self.agent_config, move_end=False)
 
         expected_output = {'dogstream': [('nagios.current_users.users', 1339511440, 1.0,
@@ -763,7 +765,7 @@ class TestNagiosPerfData(TailTestCase):
                                            'warn': '5852', 'metric_type': 'gauge',
                                            'host_name': 'localhost', 'crit': '6583',
                                            'unit': 'MB'})]}
-        self.assertEquals(expected_output, actual_output)
+        self.assertEqual(expected_output, actual_output)
 
     def test_alt_host_perfdata(self):
         from collector.checks.datadog import NagiosHostPerfData
@@ -774,7 +776,7 @@ class TestNagiosPerfData(TailTestCase):
         ])
 
         dogstream = Dogstreams.init(self.logger, self.agent_config)
-        self.assertEquals([NagiosHostPerfData], [d.__class__ for d in dogstream.dogstreams])
+        self.assertEqual([NagiosHostPerfData], [d.__class__ for d in dogstream.dogstreams])
         actual_output = dogstream.check(self.agent_config, move_end=False)
 
         expected_output = {'dogstream': [('nagios.host.pl', 1339511440, 0.0,
@@ -785,7 +787,7 @@ class TestNagiosPerfData(TailTestCase):
                                           {'warn': '3000.000000', 'metric_type': 'gauge',
                                            'host_name': 'localhost', 'min': '0.000000',
                                            'crit': '5000.000000', 'unit': 'ms'})]}
-        self.assertEquals(expected_output, actual_output)
+        self.assertEqual(expected_output, actual_output)
 
 
 if __name__ == '__main__':
